Games
=====

Sage includes a sophisticated Sudoku solver.  It also has a
Rubik's cube solver (see
`Rubik's Cube Group <../groups/sage/groups/perm_gps/cubegroup.html>`_).

.. toctree::
   :maxdepth: 1

   sage/games/sudoku
   sage/games/quantumino
   sage/games/hexad

Internals
---------

.. toctree::
   :maxdepth: 1

   sage/games/sudoku_backtrack

.. include:: ../footer.txt
